-- Time of mission patrol starting from fenced in. 1800 = 30 mins.
local globalPatrolTime = 1800;

-- Spawns a random plane out of possible templates, from a random northern airbase and sends it to harass just over the border into Turkey
function spawnBorderCrosser(name)
    local possibleTemplates = {"MiG-21 Syrian Fighter", "Mig-29 Syrian Fighter", "Su-24M Syrian Bomber", "MiG-21 Syrian Fighter Pair"}
    local missionTargetName = name;
    local spawner = SPAWN:NewWithAlias(possibleTemplates[math.random(#possibleTemplates)], missionTargetName)
    local possibleDepartureLocations = {AIRBASE.Syria.Kuweires, AIRBASE.Syria.Jirah, AIRBASE.Syria.Tabqa, AIRBASE.Syria.Abu_al_Duhur}
    local spawnedTarget = spawner:SpawnAtAirbase(AIRBASE:FindByName(possibleDepartureLocations[ math.random( #possibleDepartureLocations )]), SPAWN.Takeoff.Hot)
    BASE:E('Spawned target')
    local randomX = math.random(00220000, 00300000)
    local randomZ = math.random(00080000, 00350000)
    FlyToPoint(spawnedTarget, randomX, math.random(5000, 10000), randomZ)
    BASE:E('set Route')
    spawnedTarget:PushTask(spawnedTarget:EnRouteTaskEngageTargets(UTILS.NMToMeters(50), {"Air"}, 1000), 60);
    spawnedTarget:OptionROEWeaponFree()
    BASE:E('set Task')
end

-- Sets flag to true when units are in blue airspace
mist.flagFunc.units_in_polygon{
    units = {'[red][plane]'},
    zone = mist.getGroupPoints('BLUE_AIRSPACE'),
    flag = 'MSN_CAP_NORTH_CROSSED',
}

-- Sets flag to true when player is fenced in
mist.flagFunc.units_in_polygon{
    units = {'[blue][plane]', '[-g]Texaco 1-1', '[-g]MSN_CAP_NORTH_RETURNING', '[-g]B-AWACS', '[-g]Texaco 1-1 Escort'},
    zone = mist.getGroupPoints('BLUE_AIRSPACE'),
    flag = 'MSN_CAP_NORTH_FENCED',
}

local function onBorderCrossed()
    if trigger.misc.getUserFlag('MSN_CAP_NORTH_COMPLETE') == true or trigger.misc.getUserFlag('MSN_CAP_NORTH_COMPLETE') > 0 then
        return;
    end

    Alert("Mission CAP North\n\nALERT\nA hostile aircraft has entered our airspace.\nIntercept and engage.", 30);
end

local function onPlayerFencedIn()
    Alert("Mission CAP North\n\nPatrol started\n30 minutes left\n\nCurrent Time: ".. mist.getClockString(timer.getAbsTime()) .. "\nPatrol End Time: ".. mist.getClockString(timer.getAbsTime() + globalPatrolTime), 30);

    trigger.action.activateGroup(Group.getByName('MSN_CAP_NORTH_RETURNING'))
    mist.scheduleFunction(patrolTimeOut, {}, timer.getTime() + globalPatrolTime);
    generateEvent()
end

function patrolTimeOut()
    trigger.action.setUserFlag('MSN_CAP_NORTH_COMPLETE', true);

    Alert("Mission CAP North\n\nPatrol time is up\nMISSION COMPLETE, RTB", 60);
end

function generateEvent()
    local randomEvent = math.random(1, 3);

    -- Can spawn a border crosser between 1 and 3 times within 2/3rds of the global patrol time mins of fenced in.
    for i = 1, randomEvent, 1 do
        local randomTime = math.random(0, (globalPatrolTime / 3) * 2);
        mist.scheduleFunction(spawnBorderCrosser, {"Syrian Harasser-" .. i}, timer.getTime() + randomTime);
    end

end

-- Init
OnFlagTrue('MSN_CAP_NORTH_FENCED', onPlayerFencedIn)
OnFlagTrue('MSN_CAP_NORTH_CROSSED', onBorderCrossed)