
-- Define a SET_GROUP object that builds a collection of groups that define the EWR network.
-- Here we build the network with all the groups that have a name starting with EWR.
EWRSet = SET_GROUP:New():FilterPrefixes( "R-EWR" ):FilterStart()
Detection = DETECTION_AREAS:New( EWRSet, 30000 )

-- Setup the A2A dispatcher, and initialize it.
A2ADispatcher = AI_A2A_DISPATCHER:New( Detection )

-- Initialize the dispatcher, setting up a border zone. This is a polygon, 
-- which takes the waypoints of a late activated group with the name RED_DISPATCH_BORDER as the boundaries of the border area.
-- Any enemy crossing this border will be engaged.
RED_DISPATCH_BORDER = ZONE_POLYGON:New( "RED_DISPATCH_BORDER", GROUP:FindByName( "RED_DISPATCH_BORDER" ) )
A2ADispatcher:SetBorderZone( RED_DISPATCH_BORDER )

-- Initialize the dispatcher, setting up a radius of 100km where any airborne friendly 
-- without an assignment within 100km radius from a detected target, will engage that target.
A2ADispatcher:SetEngageRadius( 200000 )

-- SQUADRONS
-- Al-Dumayr Squadron
A2ADispatcher:SetSquadron("Al-Dumayr Squadron", AIRBASE.Syria.Al_Dumayr, { "Mig-29 Syrian Fighter", "MiG-21 Syrian Fighter" }, 28 )
A2ADispatcher:SetSquadronOverhead("Al-Dumayr Squadron", 1)
A2ADispatcher:SetSquadronGrouping("Al-Dumayr Squadron", 2.4)
A2ADispatcher:SetSquadronTakeoffFromParkingCold("Al-Dumayr Squadron")
A2ADispatcher:SetSquadronLandingAtEngineShutdown("Al-Dumayr Squadron")
A2ADispatcher:SetSquadronGci("Al-Dumayr Squadron", 900, 1200)

-- Hama Squadron
A2ADispatcher:SetSquadron("Hama Squadron", AIRBASE.Syria.Hama, { "MiG-21 Syrian Fighter", "Mig-19P Syrian Fighter" }, 24 )
A2ADispatcher:SetSquadronOverhead("Hama Squadron", 1)
A2ADispatcher:SetSquadronTakeoffFromParkingCold("Hama Squadron")
A2ADispatcher:SetSquadronLandingAtEngineShutdown("Hama Squadron")
A2ADispatcher:SetSquadronGci("Hama Squadron", 900, 1200)

-- Tabqa Squadron
A2ADispatcher:SetSquadron("Tabqa Squadron", AIRBASE.Syria.Tabqa, { "Mig-19P Syrian Fighter", "Mig-29 Syrian Fighter",  "MiG-21 Syrian Fighter" }, 19 )
A2ADispatcher:SetSquadronOverhead("Tabqa Squadron", 1)
A2ADispatcher:SetSquadronGrouping("Tabqa Squadron", 2.4)
A2ADispatcher:SetSquadronTakeoffFromParkingCold("Tabqa Squadron")
A2ADispatcher:SetSquadronLandingAtEngineShutdown("Tabqa Squadron")
A2ADispatcher:SetSquadronGci("Tabqa Squadron", 900, 1200)

-- CAP Zones
CAP_ZONE_1 = ZONE_POLYGON:New( "CAP_ZONE_1", GROUP:FindByName( "RED_CAP_1" ) )
CAP_ZONE_2 = ZONE_POLYGON:New( "CAP_ZONE_2", GROUP:FindByName( "RED_CAP_2" ) )

A2ADispatcher:SetSquadronCap("Al-Dumayr Squadron", CAP_ZONE_1, 3000, 10000, 500, 800, 1200)
A2ADispatcher:SetSquadronCapInterval("Al-Dumayr Squadron", 1, 30, 60, 1)
A2ADispatcher:SetSquadronCap("Tabqa Squadron", CAP_ZONE_2, 3000, 10000, 500, 800, 1200)
A2ADispatcher:SetSquadronCapInterval("Tabqa Squadron", 1, 30, 60, 1)

A2ADispatcher:Start()
